0.9.9 API documentation: norm.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

norm.hpp
Go to the documentation of this file.
1
15 #pragma once
16
17 // Dependency:
18 #include "../geometric.hpp"
19 #include "../gtx/quaternion.hpp"
20 #include "../gtx/component_wise.hpp"
21
22 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
23 # ifndef GLM_ENABLE_EXPERIMENTAL
24 # pragma message("GLM: GLM_GTX_norm is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
25 # else
26 # pragma message("GLM: GLM_GTX_norm extension included")
27 # endif
28 #endif
29
30 namespace glm
31 {
34
37 template<length_t L, typename T, qualifier Q>
38 GLM_FUNC_DECL T length2(vec<L, T, Q> const& x);
39
42 template<length_t L, typename T, qualifier Q>
43 GLM_FUNC_DECL T distance2(vec<L, T, Q> const& p0, vec<L, T, Q> const& p1);
44
47 template<typename T, qualifier Q>
48 GLM_FUNC_DECL T l1Norm(vec<3, T, Q> const& x, vec<3, T, Q> const& y);
49
52 template<typename T, qualifier Q>
53 GLM_FUNC_DECL T l1Norm(vec<3, T, Q> const& v);
54
57 template<typename T, qualifier Q>
58 GLM_FUNC_DECL T l2Norm(vec<3, T, Q> const& x, vec<3, T, Q> const& y);
59
62 template<typename T, qualifier Q>
63 GLM_FUNC_DECL T l2Norm(vec<3, T, Q> const& x);
64
67 template<typename T, qualifier Q>
68 GLM_FUNC_DECL T lxNorm(vec<3, T, Q> const& x, vec<3, T, Q> const& y, unsigned int Depth);
69
72 template<typename T, qualifier Q>
73 GLM_FUNC_DECL T lxNorm(vec<3, T, Q> const& x, unsigned int Depth);
74
77 template<typename T, qualifier Q>
78 GLM_FUNC_DECL T lMaxNorm(vec<3, T, Q> const& x, vec<3, T, Q> const& y);
79
82 template<typename T, qualifier Q>
83 GLM_FUNC_DECL T lMaxNorm(vec<3, T, Q> const& x);
84
86 }//namespace glm
87
88 #include "norm.inl"
glm::length2
GLM_FUNC_DECL T length2(vec< L, T, Q > const &x)
Returns the squared length of x.
glm::l1Norm
GLM_FUNC_DECL T l1Norm(vec< 3, T, Q > const &v)
Returns the L1 norm of v.
glm::distance2
GLM_FUNC_DECL T distance2(vec< L, T, Q > const &p0, vec< L, T, Q > const &p1)
Returns the squared distance between p0 and p1, i.e., length2(p0 - p1).
glm::lMaxNorm
GLM_FUNC_DECL T lMaxNorm(vec< 3, T, Q > const &x)
Returns the LMax norm of v.
glm::lxNorm
GLM_FUNC_DECL T lxNorm(vec< 3, T, Q > const &x, unsigned int Depth)
Returns the L norm of v.
glm::l2Norm
GLM_FUNC_DECL T l2Norm(vec< 3, T, Q > const &x)
Returns the L2 norm of v.
glm
Definition: common.hpp:20